@@ -1,30 +1,17 @@
-/***************************************************************************
- *   Copyright 2009-2011 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2011 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "components.h"
 
 #include <QBuffer>
 #include <QFileInfo>
 #include <KConfigGroup>
-#include <QThread>
 
-Palapeli::CollectionStorageComponent::CollectionStorageComponent(KConfigGroup* group, QMutex *groupMutex)
-	: m_group(group), m_groupMutex(groupMutex)
+Palapeli::CollectionStorageComponent::CollectionStorageComponent(KConfigGroup* group)
+	: m_group(group)
 {
 }
 
@@ -42,11 +29,10 @@ Palapeli::PuzzleComponent* Palapeli::CollectionStorageComponent::cast(Type type)
 	else if (type != Metadata)
 	{
 		const Palapeli::PuzzleComponent* arStorage = puzzle()->get(ArchiveStorage);
-		return arStorage ? arStorage->cast(type) : 0;
+		return arStorage ? arStorage->cast(type) : nullptr;
 	}
 	//try to serve metadata from cache
 	const QDateTime mtime = QFileInfo(file).lastModified();
-	m_groupMutex->lock();
 	if (m_group->readEntry("ModifyDateTime", QString()) == mtime.toString())
 	{
 		//cache is up-to-date
@@ -58,25 +44,22 @@ Palapeli::PuzzleComponent* Palapeli::CollectionStorageComponent::cast(Type type)
 		metadata.modifyProtection = m_group->readEntry("ModifyProtection", false);
 		QByteArray ar = m_group->readEntry("Thumbnail", QByteArray());
 		metadata.thumbnail.loadFromData(QByteArray::fromBase64 (ar));
-		m_groupMutex->unlock();
 		return new Palapeli::MetadataComponent(metadata);
 	}
 	else
 	{
-		m_groupMutex->unlock();
 		//read metadata from archive...
 		const Palapeli::PuzzleComponent* arStorage = puzzle()->get(ArchiveStorage);
 		if (!arStorage)
-			return 0;
+			return nullptr;
 		Palapeli::PuzzleComponent* cMetadata = arStorage->cast(Metadata);
 		if (!cMetadata)
-			return 0;
+			return nullptr;
 		//...and populate cache (image is written via a buffer
 		//because KConfig does not support QImage directly)
 		const Palapeli::PuzzleMetadata metadata = dynamic_cast<Palapeli::MetadataComponent*>(cMetadata)->metadata;
 		QBuffer buffer;
 		metadata.thumbnail.save(&buffer, "PNG");
-		m_groupMutex->lock();
 		m_group->writeEntry("Name", metadata.name);
 		m_group->writeEntry("Comment", metadata.comment);
 		m_group->writeEntry("Author", metadata.author);
@@ -84,8 +67,6 @@ Palapeli::PuzzleComponent* Palapeli::CollectionStorageComponent::cast(Type type)
 		m_group->writeEntry("ModifyProtection", metadata.modifyProtection);
 		m_group->writeEntry("ModifyDateTime", mtime.toString());
 		m_group->writeEntry("Thumbnail", buffer.data().toBase64 ());
-		m_group->sync();
-		m_groupMutex->unlock();
 		return cMetadata;
 	}
 }
